import { HighlightingState_$type } from "./HighlightingState";
import { IgxSeriesComponent } from "./igx-series-component";
import { HighlightingInfo as HighlightingInfo_internal } from "./HighlightingInfo";
import { ensureEnum, ensureBool } from "igniteui-angular-core";
/**
 * Contains contextual information about a highlighting.
*/
var IgxHighlightingInfo = /** @class */ (function () {
    function IgxHighlightingInfo() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxHighlightingInfo.prototype.createImplementation = function () {
        return new HighlightingInfo_internal();
    };
    Object.defineProperty(IgxHighlightingInfo.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgxHighlightingInfo.prototype.onImplementationCreated = function () {
    };
    IgxHighlightingInfo.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgxHighlightingInfo.prototype, "startIndex", {
        /**
         * The index of the first highlighted item.
        *
        * You can use `startIndex` to get or set the first highlighted item for the series.
        *
        * ```html
        * <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         isHighlightingEnabled="true" isCustomCategoryStyleAllowed="true" (assigningCategoryStyle)="assigningSeries($event)"   >
        * </igx-column-series>
        * ```
        */
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighlightingInfo.prototype, "endIndex", {
        /**
         * The index of the last highlighted item.
        *
        * You can use the `endIndex` to get or set the last highlighted item for the series.
        *
        * ```html
        * <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         isHighlightingEnabled="true" isCustomCategoryStyleAllowed="true"  (assigningCategoryStyle)="assigningSeries($event)"   >
        *       </igx-column-series>
        * ```
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighlightingInfo.prototype, "state", {
        /**
         * The state of the highlighting.
        *
        * You can use the `state` to get or set the transitioning state of the highlighting, between In, Out, or Static.
        */
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(HighlightingState_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighlightingInfo.prototype, "progress", {
        /**
         * A number between 0 and 1 representing the progress of the highlighting.
        *
        * You can use the `progress` property to set a number between 0 and 1 representing the progress of the highlighting.
        *
        * ```html
        * <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         isHighlightingEnabled="true" isCustomCategoryStyleAllowed="true"  (assigningCategoryStyle)="assigningSeries($event)"   >
        *       </igx-column-series>
        * ```
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighlightingInfo.prototype, "isMarker", {
        /**
         * True if this HighlightingInfo represents a marker highlighting.
        *
        * You can set the `isMarker` to True if the HighlightingInfo represents a marker highlighting. Otherwise set to false.
        *
        * ```html
        * <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         isHighlightingEnabled="true" isCustomCategoryStyleAllowed="true"  (assigningCategoryStyle)="assigningSeries($event)"   >
        *       </igx-column-series>
        * ```
        */
        get: function () {
            return this.i.c;
        },
        set: function (v) {
            this.i.c = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxHighlightingInfo.prototype, "series", {
        /**
         * The series in context.
        *
        * You can use the `series` property to get the series in context.
        *
        * ```html
        * <igx-column-series
        *         #series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         isHighlightingEnabled="true" isCustomCategoryStyleAllowed="true"  (assigningCategoryStyle)="assigningSeries($event)"   >
        *       </igx-column-series>
        * ```
        */
        get: function () {
            if (this.i.b == null) {
                return null;
            }
            if (!this.i.b.externalObject) {
                var e = IgxSeriesComponent._createFromInternal(this.i.b);
                if (e) {
                    e._implementation = this.i.b;
                }
                this.i.b.externalObject = e;
            }
            return this.i.b.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: true,
        configurable: true
    });
    return IgxHighlightingInfo;
}());
export { IgxHighlightingInfo };
//# sourceMappingURL=igx-highlighting-info.js.map