import { Type } from '@angular/core';
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxCategoryYAxisComponent } from "./igx-category-y-axis-component";
import { IgxStackedSeriesBaseComponent } from "./igx-stacked-series-base-component";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { IgxSeriesComponent } from "./igx-series-component";
import { VerticalStackedSeriesBase } from "./VerticalStackedSeriesBase";
/**
 * Base class for stacked series with a numeric x-axis and a category y-axis.
*/
export declare const IgxVerticalStackedSeriesBaseComponent_PROVIDERS: ({
    provide: typeof IgxMarkerSeriesComponent;
    useExisting: Type<any>;
} | {
    provide: typeof IgxSeriesComponent;
    useExisting: Type<any>;
})[];
export declare abstract class IgxVerticalStackedSeriesBaseComponent extends IgxStackedSeriesBaseComponent {
    /**
                                 * @hidden
                                 */
    readonly i: VerticalStackedSeriesBase;
    constructor();
    /**
     * Gets or sets the effective x-axis for the current CategorySeries object.
    */
    xAxis: IgxNumericXAxisComponent;
    /**
     * Gets or sets the effective y-axis for the current CategorySeries object.
    */
    yAxis: IgxCategoryYAxisComponent;
    /**
     * Gets whether or not the current series is vertical series
    */
    readonly isVertical: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    */
    canUseAsXAxis(axis: any): boolean;
}
